==> haskell-hackage-security-0.6.3.2-5.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.3.2
visibility:           public
id:                   hackage-security-0.6.3.2-GnoKD1HJ2hWCI0d7fM7yrV
key:                  hackage-security-0.6.3.2-GnoKD1HJ2hWCI0d7fM7yrV
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  308526f0961192118a9daacb506322f5
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hackage-security-0.6.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hackage-security-0.6.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hackage-security-0.6.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.3.2-GnoKD1HJ2hWCI0d7fM7yrV
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    containers-0.6.7
    cryptohash-sha256-0.11.102.1-GXeKCI4bd7n6SsJ2qNUYhy
    directory-1.3.8.5 ed25519-0.0.5.0-JV8Rh5YleeJ8OwsjSKmC51
    filepath-1.4.300.1 ghc-prim-0.10.0 mtl-2.3.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-D8lXj4v6hLL5fJ348I6jpg
    template-haskell-2.20.0.0 time-1.12.2 transformers-0.6.1.0
    zlib-0.7.0.0-5otxZx3SVlrUZcbECZKz5

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-security-0.6.3.2-6-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.3.2
visibility:           public
id:                   hackage-security-0.6.3.2-6h6sjFOxYt52kQVswo2JRl
key:                  hackage-security-0.6.3.2-6h6sjFOxYt52kQVswo2JRl
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  4345bcab3a0e129f84d9e0e85a25472b
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hackage-security-0.6.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hackage-security-0.6.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hackage-security-0.6.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.3.2-6h6sjFOxYt52kQVswo2JRl
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-4oSM5otI4Ra8wFWOp2kkt3
    directory-1.3.8.5 ed25519-0.0.5.0-JV8Rh5YleeJ8OwsjSKmC51
    filepath-1.4.300.1 ghc-prim-0.10.0 mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-4iAxOGYV1lQH2RPEJbrO6a
    template-haskell-2.20.0.0 time-1.12.2 transformers-0.6.1.0
    zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
